---
title: <span class="badge object-type-scalar"></span> KilohertzRotation
---
# <span class="badge object-type-scalar"></span> KilohertzRotation

Rotational Speed: Kilohertz (kHz)

## Definition

```python
# Rotational Speed: Kilohertz (kHz)
KilohertzRotation: typing.Literal["rotkhz"] = "rotkhz"
```
